# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Added

- Documentation

## 0.7.0 - 2021-08-15

### Added

- The initial project release

- Working Github Actions CI/CD files

### Removed

- Files that should have been excluded using .gitignore

    - .idea folder
    
### Fixed

- README for proper badges

- Github Actions CI/CD workflow

### Changed

- Github Actions workflow os to include windows and osx on top of ubuntu

## 0.8.0

- Function documentation

- Readthedocs integration

## 0.9.0

- pre-commit integration

## 1.0.0

- Stable release

